import axios from 'axios';

export default class {
  constructor(log, config, api) {
    // Check args
    if (!log || !config || !api) {
      return;
    }

    // Check config
    if (!config.name || !config.account_token || !config.device_token) {
      log.warn('Please enter all config fields.');
      return;
    }

    // All good
    this.hap = api.hap;
    this.log = log;
    this.name = config.name;
    this.device_token = config.device_token;
    this.account_token = config.account_token;
    this.juicenet = axios.create({
      baseURL: 'http://emwjuicebox.cloudapp.net',
      timeout: 5000,
      headers: {
        'Content-Type': 'application/json',
      },
    });

    this.informationService = new this.hap.Service.AccessoryInformation();
    this.informationService
      .setCharacteristic(this.hap.Characteristic.Manufacturer, 'eMotorWerks')
      .setCharacteristic(this.hap.Characteristic.Model, 'JuiceBox')
      .setCharacteristic(this.hap.Characteristic.SerialNumber, '123-456-789');

    this.batteryService = new this.hap.Service.BatteryService(this.name);

    this.batteryService
      .getCharacteristic(this.hap.Characteristic.BatteryLevel)
      .setProps({
        maxValue: 100,
        minValue: 0,
        minStep: 1,
      })
      .onGet(() => this.getBatteryLevel());

    this.batteryService
      .getCharacteristic(this.hap.Characteristic.ChargingState)
      .setProps({
        maxValue: 1,
      })
      .onGet(async () => this.getChargingState());

    // this.batteryService
    //     .getCharacteristic(Characteristic.StatusLowBattery)
    //     .onGet(() => this.getLowBatteryStatus())

    this.plugService = new this.hap.Service.Outlet(this.name);

    this.plugService
      .getCharacteristic(this.hap.Characteristic.OutletInUse)
      .onGet(async () => this.getOutletInUse());
  }

  getServices() {
    return [this.plugService, this.batteryService];
  }

  // Plug State
  async getOutletInUse() {
    try {
      this.log('Getting contact state...');
      const response = await this.juicenet.post('/box_api_secure', {
        cmd: 'get_state',
        account_token: this.account_token,
        device_id: 'datariot.test',
        token: this.device_token,
      });
      this.log(response.data?.state);
      switch (response.data?.state) {
        case 'standby':
          return false;
        default:
          return true;
      }
    } catch (error) {
      this.log.warn(error);
      return false;
    }
  }

  // Battery Charging State
  async getChargingState() {
    try {
      this.log('Getting current state...');
      const response = await this.juicenet.post('/box_api_secure', {
        cmd: 'get_state',
        account_token: this.account_token,
        device_id: 'datariot.test',
        token: this.device_token,
      });
      this.log(response.data?.state);
      switch (response.data?.state) {
        case 'standby':
          return 1;
        default:
          return 0;
      }
    } catch (error) {
      this.log.warn(error);
      return 0;
    }
  }

  getBatteryLevel() {
    this.log(0);
    return 0;
  }
}
